@@ -34,14 +34,13 @@ def add_apikey(service, apikey):
     apikeys[service] = apikey
 
 """
-Services preferences
+Generic Options
 """
-VIAS_MERGE = None
+options = {}
 
 
-def setvias_merge(option):
+def set_option(option, value):
     """
-    Set the value of VIAS_MERGE
+    Set the value for option
     """
-    global VIAS_MERGE
-    VIAS_MERGE = option
+    options[option] = value
